Struct GCDatapointConfig
pub struct GCDatapointConfig {
pub metadata: GCDatapointMetadata,
pub subscribers: HashMap<String, bool>,
pub publishers: HashSet<String>,
}Expand description
Config for a datapoint
Fields
metadata: GCDatapointMetadatasubscribers: HashMap<String, bool>TODO: Consider removing the subscribers Keeping track of subscribers in the config DB may speed up the lookup but it will introduce redundancy with the message broker (which also contains a list of subscribers) and may lead to inconsistency.
publishers: HashSet<String>Trait Implementations
impl Clone for GCDatapointConfig
impl Clone for GCDatapointConfig
fn clone(&self) -> GCDatapointConfig
fn clone(&self) -> GCDatapointConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for GCDatapointConfig
impl Debug for GCDatapointConfig
impl Default for GCDatapointConfig
impl Default for GCDatapointConfig
fn default() -> GCDatapointConfig
fn default() -> GCDatapointConfig
Returns the “default value” for a type. Read more